lodestonenews

package module
v0.0.0-...-3dfbb1e Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 16, 2022 License: Apache-2.0 Imports: 5 Imported by: 0

README

Lodestone News

I made a thing to fetch data from http://na.lodestonenews.com/ that I use in a simple Discord bot. This is probably bad and dumb, so I wouldn't think about it too much.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type CurrentMainteenance

type CurrentMainteenance struct {
	Companion []LodestoneNewsResponse `json:"companion"`
	Game      []LodestoneNewsResponse `json:"game"`
	Lodestone []LodestoneNewsResponse `json:"lodestone"`
	Mog       []LodestoneNewsResponse `json:"mog"`
	PSN       []LodestoneNewsResponse `json:"psn"`
}

func CurrentMaintenance

func CurrentMaintenance(locale Region) (currentMaintenance CurrentMainteenance, err error)

type LodestoneNewsResponse

type LodestoneNewsResponse struct {
	ID          string    `json:"id"`
	URL         string    `json:"url"`
	Title       string    `json:"title"`
	Time        time.Time `json:"time"`
	Image       string    `json:"image"`
	Description string    `json:"description"`
	Start       time.Time `json:"start"`
	End         time.Time `json:"end"`
	Emergency   bool      `json:"emergency"`
	Current     bool      `json:"current"`
	Category    string    `json:"category"`
}

func Developers

func Developers(locale Region) (status []LodestoneNewsResponse, err error)

func Feed

func Feed(locale Region) (status []LodestoneNewsResponse, err error)

func Maintenance

func Maintenance(locale Region) (maintenance []LodestoneNewsResponse, err error)

func Notices

func Notices(locale Region) (notices []LodestoneNewsResponse, err error)

func Status

func Status(locale Region) (status []LodestoneNewsResponse, err error)

func Topics

func Topics(locale Region) (news []LodestoneNewsResponse, err error)

func Updates

func Updates(locale Region) (updates []LodestoneNewsResponse, err error)

type Region

type Region string
const (
	NorthAmerica  Region = "na"
	EuropeanUnion Region = "eu"
	France        Region = "fr"
	Germany       Region = "de"
	Japan         Region = "jp"
)

Jump to